==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nodes/node/group/buckets/bucket/action/action/NxActionFinTimeoutNodesNodeGroupBucketsBucketActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nodes.node.group.buckets.bucket.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionFinTimeoutGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-fin-timeout-nodes-node-group-buckets-bucket-actions-case {
 *   uses nx-action-fin-timeout-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nodes/node/(urn:opendaylight:flow:inventory?revision=2013-08-19)group/buckets/bucket/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-fin-timeout-nodes-node-group-buckets-bucket-actions-case</i>
 *
 */
public interface NxActionFinTimeoutNodesNodeGroupBucketsBucketActionsCase
    extends
    DataObject,
    Augmentable<NxActionFinTimeoutNodesNodeGroupBucketsBucketActionsCase>,
    NxActionFinTimeoutGrouping,
    Action
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-fin-timeout-nodes-node-group-buckets-bucket-actions-case");


}

==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nodes/node/group/buckets/bucket/action/action/NxActionFinTimeoutNodesNodeGroupBucketsBucketActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nodes.node.group.buckets.bucket.action.action;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionFinTimeoutGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-fin-timeout-nodes-node-group-buckets-bucket-actions-case {
 *   uses nx-action-fin-timeout-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/nodes/node/(urn:opendaylight:flow:inventory?revision=2013-08-19)group/buckets/bucket/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-fin-timeout-nodes-node-group-buckets-bucket-actions-case</i>
 *
 */
public interface NxActionFinTimeoutNodesNodeGroupBucketsBucketActionsCase
    extends
    DataObject,
    Augmentable<NxActionFinTimeoutNodesNodeGroupBucketsBucketActionsCase>,
    NxActionFinTimeoutGrouping,
    Action
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-fin-timeout-nodes-node-group-buckets-bucket-actions-case");


}
